@@ -1,4 +1,4 @@
-"""The archicad package from GRAPHISOFT
+"""The archicad package from Graphisoft
 """
 
 from .handlers import handle_dependencies
