@@ -1,4 +1,4 @@
-"""GRAPHISOFT"""
+"""Graphisoft"""
 
 import argparse
 from urllib.request import Request
@@ -19,12 +19,12 @@ def create_request(port: int) -> Request:
 
 
 class ACConnection:
-    """Represents a living connection to an existing ARCHICAD instance
+    """Represents a living connection to an existing Archicad instance
     
     Attributes:
-        version (:obj:`int`): The version of the current ARCHICAD instance.
-        build (:obj:`int`): The build number of the current ARCHICAD instance.
-        lang (:obj:`str`): The language code of the current ARCHICAD instance.
+        version (:obj:`int`): The version of the current Archicad instance.
+        build (:obj:`int`): The build number of the current Archicad instance.
+        lang (:obj:`str`): The language code of the current Archicad instance.
         commands: The commands can be called through this object. 
         types: The data types of commands can be access through this object.
         utilities: Some other useful commands can be called through this object. 
@@ -43,10 +43,10 @@ class ACConnection:
 
     @staticmethod
     def connect(port: Optional[int] = None):
-        """Tries to connect to a running ARCHICAD instance.
+        """Tries to connect to a running Archicad instance.
         
         Args:
-            port (:obj:`int`, optional): The ARCHICAD's port. If not given, the command line or the default port will be used.
+            port (:obj:`int`, optional): The Archicad's port. If not given, the command line or the default port will be used.
         
         Raises:
             ConnectionError: When the connection is unsuccessful.
@@ -59,7 +59,7 @@ class ACConnection:
             try:
                 conn = ACConnection(port)
                 if not conn:
-                    raise ConnectionError(f"Could not connect to ARCHICAD on port {port}")
+                    raise ConnectionError(f"Could not connect to Archicad on port {port}")
             except URLError:
                 pass
         else:
@@ -85,7 +85,7 @@ class ACConnection:
         """
         parser = argparse.ArgumentParser(add_help=False)
         parser.add_argument('--port', type=int, default=None)
-        args = parser.parse_args()
+        args, _ = parser.parse_known_args()
         return args.port
         
     @staticmethod
