@@ -1,4 +1,4 @@
-"""GRAPHISOFT
+"""Graphisoft
 """
 from uuid import UUID
 from typing import Union, Optional, List
@@ -1622,7 +1622,7 @@ class NavigatorItem(_ACBaseType):
         navigatorItemId (:obj:`NavigatorItemId`): The identifier of a navigator item.
         prefix (:obj:`str`): Prefix of the name of the navigator item.
         name (:obj:`str`): Name of the navigator item.
-        type (:obj:`str`): Possible types of a navigator item. Most of the names are self-explanatory, the only exception is 'UndefinedItem', which means that the type of this navigator item cannot be retrieved from ARCHICAD yet.
+        type (:obj:`str`): Possible types of a navigator item. Most of the names are self-explanatory, the only exception is 'UndefinedItem', which means that the type of this navigator item cannot be retrieved from Archicad yet.
         sourceNavigatorItemId (:obj:`NavigatorItemId`, optional): The identifier of a navigator item.
         children (:obj:`list` of :obj:`NavigatorItemArrayItem`, optional): List of navigator items.
 
