@@ -1,4 +1,4 @@
-"""GRAPHISOFT
+"""Graphisoft
 """
 from typing import Dict, Any, List, Tuple, Optional, Union
 from urllib.request import Request, urlopen
@@ -20,7 +20,7 @@ def post_command(req: Request, jsonStr: str) -> Dict[str, Any]:
 
 
 class Commands:
-    """Collection of the ARCHICAD JSON interface commands
+    """Collection of the Archicad JSON interface commands
     """
     def __init__(self, req: Request):
         assert req is not None
@@ -458,12 +458,12 @@ class Commands:
         return NavigatorTree(**result["result"]["navigatorTree"])
 
     def GetProductInfo(self) -> Tuple[int, int, str]:
-        """Accesses the version information from the running ARCHICAD.
+        """Accesses the version information from the running Archicad.
 
         Returns:
-            :obj:`int`: The version of the running ARCHICAD.
-            :obj:`int`: The build number of the running ARCHICAD.
-            :obj:`str`: The language code of the running ARCHICAD.
+            :obj:`int`: The version of the running Archicad.
+            :obj:`int`: The build number of the running Archicad.
+            :obj:`str`: The language code of the running Archicad.
 
         """
 
@@ -536,7 +536,7 @@ class Commands:
         return publisherSetNamesListBuilder(result["result"]["publisherSetNames"])
 
     def IsAlive(self) -> bool:
-        """Checks if the ARCHICAD connection is alive.
+        """Checks if the Archicad connection is alive.
 
         Returns:
             :obj:`bool`: Returns true if the connection is alive.
