@@ -15,7 +15,7 @@ def _find_in_tree(treeRootItem, itemattr, childrenattr, criterion) -> list:
 
 
 class Utilities:
-    """ Utility functions for the archicad module.
+    """ Utility functions for the Archicad module.
     """
     def __init__(self, actypes: Types, accommands: Commands):
         self.actypes = actypes
@@ -95,7 +95,7 @@ class Utilities:
         Returns:
             :obj:`str`: The display value of the enumeration property value.
         """
-        return next(p.enumValue.displayValue for p in self.accommands.GetDetailsOfProperties ([propertyId])[0].propertyDefinition.possibleEnumValues if p.enumValue.enumValueId == enumValueId)
+        return next(p.enumValue.displayValue for p in self.accommands.GetDetailsOfProperties ([propertyId])[0].propertyDefinition.possibleEnumValues if p.enumValue.enumValueId.to_dict() == enumValueId.to_dict())
 
 
     def GetValueFromPropertyValue(self, propertyId: PropertyId, propertyValue: PropertyValue) -> Any:
